==> flutter_catalogue_widgets-0.0.6.tar.gz: lib/custom-carousel.dart <==
/*
Description:

Creates a horizontal scroll view or carousel of a list of widgets.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-carousel.dart';

Usage:

A list of CarouselList class consisting of an widget is passed.CarouselParameters class is used to define the height and childAspectRatio for the carousel.
 void Function(int,) callback function defined returns the index of the carousel widget tapped on.



- Defining the callback and Carousel objects

 CarouselList carouselObj1 = new CarouselList(
        widget: Icon(Icons.person,size: 50,)

    );
    CarouselList carouselObj2 = new CarouselList(
        widget: Icon(Icons.cloud,size: 50,)
    );
    CarouselList carouselObj3 = new CarouselList(
        widget: Container(color:Colors.blue,height:100,width:80)
    );
    CarouselList carouselObj4 = new CarouselList(
        widget: Container(color:Colors.red,height:50,width:50)

    );
    CarouselList carouselObj5 = new CarouselList(
        widget: Container(color:Colors.yellow,height:100,width:80)
    );
    CarouselList carouselObj6 = new CarouselList(
        widget: Container(color:Colors.purple,height:100,width:80)
    );
    CarouselList carouselObj7 = new CarouselList(
        widget: Container(color:Colors.green,height:50,width:50)
    );

    List<CarouselList> CarouselWidgetList = [carouselObj1,carouselObj2,carouselObj3,carouselObj4,carouselObj5,carouselObj6,carouselObj7];

    onclickCarousel(int nIndex,) {
      print(nIndex);

    }
    CarouselParameters obj = new CarouselParameters(height: 500,childAspectRatio:2.75,width:400);

- Object call for the widget


   CustomCarousel(CarouselWidgetList,obj,onclickCarousel),


Author:
Gautami Yeole
*/

import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'consts.dart' as cons;
import 'widget-classesUsed.dart';


class CustomCarousel extends StatefulWidget {
  List<CarouselList> prod = [];
  CarouselParameters param;
   void Function(int,) callback;

  CustomCarousel(this.prod,this.param,this.callback
      ); //passing the CarouselList collection and callback function from the container
  @override
  State<StatefulWidget> createState() {
    CarouselParameters obj = new CarouselParameters(height: cons.heightTwoHundred,childAspectRatio: cons.heightTwo);
    if(prod==null&&param==null)
      {
        return _stateCustomCarousel(cons.defaultCarouselList,obj,null);
      }

    else
      {
        return _stateCustomCarousel(this.prod,this.param,this.callback);
      }
  }
}
class _stateCustomCarousel extends State<CustomCarousel> {
  List<CarouselList> prod = [];
  CarouselParameters param;
  final void Function(int,) callback;
  _stateCustomCarousel(this.prod,this.param,this.callback
      ); //passing the CarouselList collection and callback function from the container
  @override
  Widget build(BuildContext context) {
    return _showCarouselList(this.prod);
  }
  Widget _showCarouselList(List<CarouselList> c) {
    return SafeArea(
        child: Container(
         height: (param.height!=null)?param.height:cons.heightThreeHundred,
          width:(param.width!=null)?param.width:cons.heightFourHundred,

          child: GridView(
              gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
                  crossAxisCount: cons.intOne, childAspectRatio:  (param.childAspectRatio!=null)?param.childAspectRatio:cons.pointEight),
              scrollDirection: Axis.horizontal,
              children: c
                  .map((item) => (Row(
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                children: <Widget>[

                  GestureDetector(
                    onTap: () { (callback!=null)?callback(c.indexOf(item),):null; },
                    child: Expanded(
                      child:
                          item.widget,

                    ),
                  )
                ],
              )))
                  .toList()),
        ));
  }
}

==> flutter_catalogue_widgets-0.0.14.tar.gz: lib/custom-carousel.dart <==
/*
Description:

Creates a horizontal scroll view or carousel of a list of widgets.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-carousel.dart';

Usage:

A list of CarouselList class consisting of an widget is passed.CarouselParameters class is used to define the height and childAspectRatio for the carousel.
 void Function(int,) callback function defined returns the index of the carousel widget tapped on.



- Defining the callback and Carousel objects

 CarouselList carouselObj1 = new CarouselList(
        widget: Icon(Icons.person,size: 50,)

    );
    CarouselList carouselObj2 = new CarouselList(
        widget: Icon(Icons.cloud,size: 50,)
    );
    CarouselList carouselObj3 = new CarouselList(
        widget: Container(color:Colors.blue,height:100,width:80)
    );
    CarouselList carouselObj4 = new CarouselList(
        widget: Container(color:Colors.red,height:50,width:50)

    );
    CarouselList carouselObj5 = new CarouselList(
        widget: Container(color:Colors.yellow,height:100,width:80)
    );
    CarouselList carouselObj6 = new CarouselList(
        widget: Container(color:Colors.purple,height:100,width:80)
    );
    CarouselList carouselObj7 = new CarouselList(
        widget: Container(color:Colors.green,height:50,width:50)
    );

    List<CarouselList> CarouselWidgetList = [carouselObj1,carouselObj2,carouselObj3,carouselObj4,carouselObj5,carouselObj6,carouselObj7];

    onclickCarousel(int nIndex,) {
      print(nIndex);

    }
    CarouselParameters obj = new CarouselParameters(height: 500,childAspectRatio:2.75,width:400);

- Object call for the widget


   CustomCarousel(CarouselWidgetList,obj,onclickCarousel),


Author:
Gautami Yeole
*/

import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'consts.dart' as cons;
import 'widget-classesUsed.dart';


// ignore: must_be_immutable
class CustomCarousel extends StatefulWidget {
  List<CarouselList> prod = [];
  CarouselParameters param;
   void Function(int,) callback;

  CustomCarousel(this.prod,this.param,this.callback
      ); //passing the CarouselList collection and callback function from the container
  @override
  State<StatefulWidget> createState() {
    CarouselParameters obj = new CarouselParameters(height: cons.heightTwoHundred,childAspectRatio: cons.heightTwo);
    if(prod==null&&param==null)
      {
        return _StateCustomCarousel(cons.defaultCarouselList,obj,null);
      }

    else
      {
        return _StateCustomCarousel(this.prod,this.param,this.callback);
      }
  }
}
class _StateCustomCarousel extends State<CustomCarousel> {
  List<CarouselList> prod = [];
  CarouselParameters param;
  final void Function(int,) callback;
  _StateCustomCarousel(this.prod,this.param,this.callback
      ); //passing the CarouselList collection and callback function from the container
  @override
  Widget build(BuildContext context) {
    return _showCarouselList(this.prod);
  }
  Widget _showCarouselList(List<CarouselList> c) {
    return SafeArea(
        child: Container(
         height: (param.height!=null)?param.height:cons.heightThreeHundred,
          width:(param.width!=null)?param.width:cons.heightFourHundred,

          child: GridView(
              gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
                  crossAxisCount: cons.intOne, childAspectRatio:  (param.childAspectRatio!=null)?param.childAspectRatio:cons.pointEight),
              scrollDirection: Axis.horizontal,
              children: c
                  .map((item) => (Row(
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                children: <Widget>[

                  GestureDetector(
                    // ignore: unnecessary_statements
                    onTap: () { (callback!=null)?callback(c.indexOf(item),):null; },
                    child: Expanded(
                      child:
                          item.widget,

                    ),
                  )
                ],
              )))
                  .toList()),
        ));
  }
}
